@@ -80,7 +80,7 @@ except ImportError:
 from pip.req import parse_requirements
 
 
-__version__ = 2, 1, 0
+__version__ = 2, 1, 1
 
 
 ITS_FINE_ITS_FINE = 0
@@ -230,7 +230,7 @@ def peep_hash(argv):
 class EmptyOptions(object):
     """Fake optparse options for compatibility with pip<1.2
 
-    pip<1.2 had a bug in parse_requirments() in which the ``options`` kwarg
+    pip<1.2 had a bug in parse_requirements() in which the ``options`` kwarg
     was required. We work around that by passing it a mock object.
 
     """
@@ -381,9 +381,9 @@ class DownloadedReq(object):
             raise RuntimeError("The archive '%s' didn't start with the package name '%s', so I couldn't figure out the version number. My bad; improve me." %
                                (filename, package_name))
 
-        get_version =  (version_of_wheel
-                        if self._downloaded_filename().endswith('.whl')
-                        else version_of_archive)
+        get_version = (version_of_wheel
+                       if self._downloaded_filename().endswith('.whl')
+                       else version_of_archive)
         return get_version(self._downloaded_filename(), self._project_name())
 
     def _is_always_unsatisfied(self):
@@ -572,7 +572,10 @@ class DownloadedReq(object):
         """
         other_args = list(requirement_args(self._argv, want_other=True))
         archive_path = join(self._temp_path, self._downloaded_filename())
-        run_pip(['install'] + other_args + ['--no-deps', archive_path])
+        # -U so it installs whether pip deems the requirement "satisfied" or
+        # not. This is necessary for GitHub-sourced zips, which change without
+        # their version numbers changing.
+        run_pip(['install'] + other_args + ['--no-deps', '-U', archive_path])
 
     @memoize
     def _actual_hash(self):
@@ -733,18 +736,20 @@ def downloaded_reqs_from_path(path, argv):
     :arg argv: The commandline args, starting after the subcommand
 
     """
+    def downloaded_reqs(parsed_reqs):
+        """Just avoid repeating this list comp."""
+        return [DownloadedReq(req, argv) for req in parsed_reqs]
+
     try:
-        return [DownloadedReq(req, argv) for req in
-                parse_requirements(path, options=EmptyOptions())]
+        return downloaded_reqs(parse_requirements(path, options=EmptyOptions()))
     except TypeError:
         # session is a required kwarg as of pip 6.0 and will raise
         # a TypeError if missing. It needs to be a PipSession instance,
         # but in older versions we can't import it from pip.download
         # (nor do we need it at all) so we only import it in this except block
         from pip.download import PipSession
-        return [DownloadedReq(req, argv) for req in
-                parse_requirements(path, options=EmptyOptions(),
-                                   session=PipSession())]
+        return downloaded_reqs(parse_requirements(
+                path, options=EmptyOptions(), session=PipSession()))
 
 
 def peep_install(argv):
@@ -837,6 +842,6 @@ def exception_handler(exc_type, exc_value, exc_tb):
 if __name__ == '__main__':
     try:
         exit(main())
-    except Exception as exc:
+    except Exception:
         exception_handler(*sys.exc_info())
-        exit(1)
+        exit(SOMETHING_WENT_WRONG)
